##  Inverting Applied Fields on Relation Filter
You can invert the applied filter in the filter group settings by clicking the gear icon in either the filter panel or the filter bar and then selecting none of the relation field filters.
![Inverting the Fields on Relation Filter](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27527c597a441014af88e9f9ae904102_LowRes.png)
Inverting the Fields on Relation Filter
